Overview
========

This add-on provides a number of integration points between `MailChimp
<http://www.mailchimp.com>`_ and `Plone <http://www.plone.org>`_:

1. Assign interest groups to existing content and
   automatically expose the result sets as RSS-feeds.
2. Sign up form in both portlet- and view format, complete with
   an optional selection of interest groups.
3. Create newsletter campaigns from existing content using the
   dashboard, with conditional interest group merge tags.
4. Moderation built-in.

Quick start:

Define a set of interest groups for one or more lists, configure Plone
with your API key and start tagging content.


Compatibility
-------------

- Plone 3 and 4 are supported.
- Works with both Archetypes or Dexterity content.


Localization
------------

The product is currently localized into:

* Danish

Contributions are welcome!


Author
------

Malthe Borch <mborch@gmail.com>
